document.addEventListener('DOMContentLoaded', () => {
  // Smooth scroll for navigation links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      document.querySelector(this.getAttribute('href')).scrollIntoView({
        behavior: 'smooth'
      });
    });
  });

  // Animation on scroll
  const observerOptions = {
    threshold: 0.1
  };

  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.classList.add('animate');
      }
    });
  }, observerOptions);

  document.querySelectorAll('.feature-card, .game-card, .price-card').forEach((el) => observer.observe(el));

  // Dynamic background effect for hero section
  const hero = document.querySelector('.hero');
  let mouseX = 0;
  let mouseY = 0;

  hero.addEventListener('mousemove', (e) => {
    mouseX = e.clientX / window.innerWidth;
    mouseY = e.clientY / window.innerHeight;
    
    hero.style.background = `linear-gradient(
      ${135 + mouseX * 30}deg, 
      var(--primary), 
      var(--secondary)
    )`;
  });

  // Mobile menu toggle
  const mobileMenuBtn = document.createElement('button');
  mobileMenuBtn.classList.add('mobile-menu-btn');
  mobileMenuBtn.innerHTML = '☰';
  document.querySelector('nav').appendChild(mobileMenuBtn);

  mobileMenuBtn.addEventListener('click', () => {
    document.querySelector('.nav-links').classList.toggle('show');
  });
});